@@ -24,8 +24,8 @@ import re
 import virtualenv
 import sys
 import time
-from os import makedirs, walk, symlink
-from os.path import abspath, join, exists, dirname, basename
+from os import makedirs, walk, symlink, mkdir
+from os.path import abspath, join, lexists, exists, dirname, basename
 from installable import Installable
 from oerpenv import tools, defaults
 from virtualenv import subprocess
@@ -62,7 +62,7 @@ class OpenERPEnvironment:
             dst_config_filename = join(abspath(path), 'environment.conf')
 
             if not lexists(path):
-                os.mkdir(abspath(path))
+                mkdir(abspath(path))
             urlretrieve(src_config_filename, dst_config_filename)
             config_filename = dst_config_filename
 
